You are viewing a plain text version of this content. The canonical link for it is here.
Posted to wsrf-dev@ws.apache.org by ip...@apache.org on 2005/05/06 01:30:37 UTC

svn commit: r168465 - in /incubator/apollo/trunk: ./ src/java/org/apache/ws/resource/i18n/ src/java/org/apache/ws/resource/properties/query/ src/java/org/apache/ws/resource/properties/query/impl/ src/java/org/apache/ws/resource/properties/query/xpath/impl/ src/java/org/apache/ws/resource/properties/v2004_06/porttype/impl/ src/java/org/apache/ws/resource/properties/v2004_11/porttype/impl/ wsa-xbeans/src/java/

Author: ips
Date: Thu May  5 16:30:35 2005
New Revision: 168465

URL: http://svn.apache.org/viewcvs?rev=168465&view=rev
Log:
misc minor

Removed:
    incubator/apollo/trunk/wsa-xbeans/src/java/
Modified:
    incubator/apollo/trunk/maven.xml
    incubator/apollo/trunk/src/java/org/apache/ws/resource/i18n/Keys.java
    incubator/apollo/trunk/src/java/org/apache/ws/resource/properties/query/QueryEngine.java
    incubator/apollo/trunk/src/java/org/apache/ws/resource/properties/query/impl/QueryEngineImpl.java
    incubator/apollo/trunk/src/java/org/apache/ws/resource/properties/query/xpath/impl/JaxenXPathExpressionEvaluator.java
    incubator/apollo/trunk/src/java/org/apache/ws/resource/properties/query/xpath/impl/XalanXPathExpressionEvaluator.java
    incubator/apollo/trunk/src/java/org/apache/ws/resource/properties/v2004_06/porttype/impl/QueryResourcePropertiesPortTypeImpl.java
    incubator/apollo/trunk/src/java/org/apache/ws/resource/properties/v2004_11/porttype/impl/QueryResourcePropertiesPortTypeImpl.java

Modified: incubator/apollo/trunk/maven.xml
URL: http://svn.apache.org/viewcvs/incubator/apollo/trunk/maven.xml?rev=168465&r1=168464&r2=168465&view=diff
==============================================================================
--- incubator/apollo/trunk/maven.xml (original)
+++ incubator/apollo/trunk/maven.xml Thu May  5 16:30:35 2005
@@ -137,21 +137,20 @@
   </postGoal>
 
   <goal name="extract-wsdl-jar">
-    <echo>Extracting Wsdls from: ${wsdljar}</echo>
+    <echo>Extracting WSDLs from ${wsdljar} to ${spec.wsdl.dest.dir} ...</echo>
     <mkdir dir="${maven.build.dir}/temp-wsdl" />
     <mkdir dir="${spec.wsdl.dest.dir}" />   
-      <unzip src="${wsdljar}"
-             dest="${maven.build.dir}/temp-wsdl">
-          <patternset>
-              <include name="**/*.wsdl"/>
-              <include name="**/*.xsd"/>
-          </patternset>
-      </unzip>
-      <copy todir="${spec.wsdl.dest.dir}">
-      	<fileset dir="${maven.build.dir}/temp-wsdl/schema/src/src/wsdl"/>         	
-      </copy>
-  
-     <delete dir="${maven.build.dir}/temp-wsdl" />
+    <unzip src="${wsdljar}"
+           dest="${maven.build.dir}/temp-wsdl">
+      <patternset>
+        <include name="**/*.wsdl"/>
+        <include name="**/*.xsd"/>
+      </patternset>
+    </unzip>
+    <copy todir="${spec.wsdl.dest.dir}">
+      <fileset dir="${maven.build.dir}/temp-wsdl/schema" />         	
+    </copy>
+    <delete dir="${maven.build.dir}/temp-wsdl" />
   </goal>
 
   <goal name="deploy">

Modified: incubator/apollo/trunk/src/java/org/apache/ws/resource/i18n/Keys.java
URL: http://svn.apache.org/viewcvs/incubator/apollo/trunk/src/java/org/apache/ws/resource/i18n/Keys.java?rev=168465&r1=168464&r2=168465&view=diff
==============================================================================
--- incubator/apollo/trunk/src/java/org/apache/ws/resource/i18n/Keys.java (original)
+++ incubator/apollo/trunk/src/java/org/apache/ws/resource/i18n/Keys.java Thu May  5 16:30:35 2005
@@ -511,9 +511,13 @@
      */
     String PROP_DOC = "PROP_DOC";
     /**
-     * @msg Xalan XPath expression evaluator (Xalan version is {0}
+     * @msg Xalan XPath expression evaluator (Xalan version is {0})
      */
-    String XALAN_VERSION = "XALAN_VERSION";
+    String XALAN_EVALUATOR = "XALAN_EVALUATOR";
+    /**
+     * @msg Jaxen XPath expression evaluator
+     */
+    String JAXEN_EVALUATOR = "JAXEN_EVALUATOR";
     /**
      * @msg XPath Expression was null.
      */

Modified: incubator/apollo/trunk/src/java/org/apache/ws/resource/properties/query/QueryEngine.java
URL: http://svn.apache.org/viewcvs/incubator/apollo/trunk/src/java/org/apache/ws/resource/properties/query/QueryEngine.java?rev=168465&r1=168464&r2=168465&view=diff
==============================================================================
--- incubator/apollo/trunk/src/java/org/apache/ws/resource/properties/query/impl/QueryEngineImpl.java (original)
+++ incubator/apollo/trunk/src/java/org/apache/ws/resource/properties/query/impl/QueryEngineImpl.java Thu May  5 16:30:35 2005
@@ -45,175 +45,178 @@
 import java.util.Map;
 
 /**
- * LOG-DONE
- * Executes queries on resource property sets. The engine looks for evaluators under the
- * "wsrf/query/eval" JNDI context.
+ * LOG-DONE Executes queries on resource property sets. The engine looks for evaluators under the "wsrf/query/eval" JNDI
+ * context.
  *
  * @see ResourcePropertySet
  */
 public class QueryEngineImpl
-   implements QueryEngine
+        implements QueryEngine
 {
-   /**
-    * DOCUMENT_ME
-    */
-   private static final Log LOG                     = LogFactory.getLog( QueryEngineImpl.class.getName(  ) );
-   public static final Messages MSG = MessagesImpl.getInstance();
-   private static String    QUERY_EVALUATOR_CONTEXT = JndiConstants.CONTEXT_NAME_BASE + "/query/eval";
-   private Map              m_evaluators            = Collections.synchronizedMap( new HashMap(  ) );
-
-   /**
-    * Creates a new {@link QueryEngineImpl} object.
-    */
-   public QueryEngineImpl(  )
-   {
-      // TODO: refactor this
-      //refresh();
-      //registerEvaluator( QueryConstants.DIALECT_URI__XPATH1_0, new XmlBeansXPathExpressionEvaluator() );
-      try
-      {
-         /*registerEvaluator( QueryConstants.DIALECT_URI__XPATH1_0,
-                            new XmlBeansXPathExpressionEvaluator() );*/
-         registerEvaluator( QueryConstants.DIALECT_URI__XPATH1_0,
-                            new XalanXPathExpressionEvaluator() );
-      }
-      catch ( UnknownQueryExpressionDialectException uqede )
-      {
-         throw new JAXRPCException( uqede );
-      }
-   }
-
-   /**
-    *
-    * @param dialect
-    *
-    * @return
-    */
-   public ExpressionEvaluator getEvaluator( URI dialect )
-   {
-      return (ExpressionEvaluator) m_evaluators.get( dialect );
-   }
-
-   /**
-    * DOCUMENT_ME
-    *
-    * @param queryExpr           DOCUMENT_ME
-    * @param resourcePropertySet DOCUMENT_ME
-    * @return DOCUMENT_ME
-    *
-    * @throws UnknownQueryExpressionDialectException
-    *                                       DOCUMENT_ME
-    * @throws QueryEvaluationErrorException DOCUMENT_ME
-    * @throws InvalidQueryExpressionException
-    *                                       DOCUMENT_ME
-    * @throws UnknownQueryExpressionDialectFaultException
-    *                                       DOCUMENT_ME
-    */
-   public Object executeQuery( QueryExpression queryExpr,
-                               ResourcePropertySet resourcePropertySet )
-   throws UnknownQueryExpressionDialectException, 
-          QueryEvaluationErrorException, 
-          InvalidQueryExpressionException
-   {
-      ExpressionEvaluator evaluator = getEvaluator( queryExpr.getDialect(  ) );
-      if ( evaluator == null )
-      {
-         throw new UnknownQueryExpressionDialectException( queryExpr.getDialect(  ) );
-      }
-      if(LOG.isDebugEnabled())
-      {
-          LOG.debug(MSG.getMessage( Keys.EXEC_QUERY) + ": " + queryExpr +
-                     MSG.getMessage( Keys.ON_RP_SET) + resourcePropertySet.getMetaData().getName().toString());
-      }
-      return evaluator.evaluate( queryExpr, resourcePropertySet );
-   }
-
-    /**
-    * Reinitializes the evaluators list from JNDI context. If any evaluators were added using {@link
-    * #registerEvaluator(ExpressionEvaluator) registerEvaluator()} function they will be lost.
-    */
-   public synchronized void refresh(  )
-   {
-      m_evaluators.clear(  );
-      NamingEnumeration list = null;
-      try
-      {
-         Context initialContext = new InitialContext(  );
-         list = initialContext.list( QUERY_EVALUATOR_CONTEXT );
-         NameClassPair       pair      = null;
-         ExpressionEvaluator evaluator = null;
-         while ( list.hasMore(  ) )
-         {
-            pair         = (NameClassPair) list.next(  );
-            evaluator =
-               (ExpressionEvaluator) JNDIUtils.lookup( initialContext,
-                                                       QUERY_EVALUATOR_CONTEXT + "/" + pair.getName(  ),
-                                                       ExpressionEvaluator.class );
-            registerEvaluator( evaluator );
-         }
-      }
-      catch ( NamingException e )
-      {
-         LOG.error( MSG.getMessage( Keys.QUERY_ENG_INIT_ERROR,e ));
-      }
-      finally
-      {
-         if ( list != null )
-         {
-            try
+    /**
+     * DOCUMENT_ME
+     */
+    private static final Log LOG = LogFactory.getLog( QueryEngineImpl.class.getName() );
+    public static final Messages MSG = MessagesImpl.getInstance();
+    private static String QUERY_EVALUATOR_CONTEXT = JndiConstants.CONTEXT_NAME_BASE + "/query/eval";
+    private Map m_evaluators = Collections.synchronizedMap( new HashMap() );
+
+    /**
+     * Creates a new {@link QueryEngineImpl} object.
+     */
+    public QueryEngineImpl()
+    {
+        // TODO: refactor this
+        //refresh();
+        //registerEvaluator( QueryConstants.DIALECT_URI__XPATH1_0, new XmlBeansXPathExpressionEvaluator() );
+        try
+        {
+            /*registerEvaluator( QueryConstants.DIALECT_URI__XPATH1_0,
+                               new JaxenXPathExpressionEvaluator() );*/
+            registerEvaluator( QueryConstants.DIALECT_URI__XPATH1_0,
+                    new XalanXPathExpressionEvaluator() );
+        }
+        catch ( UnknownQueryExpressionDialectException uqede )
+        {
+            throw new JAXRPCException( uqede );
+        }
+    }
+
+    /**
+     * @param dialect
+     *
+     * @return
+     */
+    public ExpressionEvaluator getEvaluator( URI dialect )
+    {
+        return (ExpressionEvaluator) m_evaluators.get( dialect );
+    }
+
+    /**
+     * @see QueryEngine#executeQuery(org.apache.ws.resource.properties.query.QueryExpression,
+            *      org.apache.ws.resource.properties.ResourcePropertySet)}
+     */
+    public Object executeQuery( QueryExpression queryExpr,
+                                ResourcePropertySet resourcePropertySet )
+            throws UnknownQueryExpressionDialectException,
+            QueryEvaluationErrorException,
+            InvalidQueryExpressionException
+    {
+        if ( LOG.isDebugEnabled() )
+        {
+            LOG.debug( MSG.getMessage( Keys.EXEC_QUERY ) + ": " + queryExpr +
+                    MSG.getMessage( Keys.ON_RP_SET ) + resourcePropertySet.getMetaData().getName().toString() );
+        }
+        return getEvaluator( queryExpr ).evaluate( queryExpr, resourcePropertySet );
+    }
+
+    /**
+     * @see QueryEngine#executeQuery(org.apache.ws.resource.properties.query.QueryExpression, Object)}
+     */
+    public Object executeQuery( QueryExpression queryExpr,
+                                Object evalContext )
+            throws UnknownQueryExpressionDialectException,
+            QueryEvaluationErrorException,
+            InvalidQueryExpressionException
+    {
+        return getEvaluator( queryExpr ).evaluate( queryExpr, evalContext );
+    }
+
+    private ExpressionEvaluator getEvaluator( QueryExpression queryExpr )
+            throws UnknownQueryExpressionDialectException
+    {
+        ExpressionEvaluator evaluator = getEvaluator( queryExpr.getDialect() );
+        if ( evaluator == null )
+        {
+            throw new UnknownQueryExpressionDialectException( queryExpr.getDialect() );
+        }
+        return evaluator;
+    }
+
+    /**
+     * Reinitializes the evaluators list from JNDI context. If any evaluators were added using {@link
+     * #registerEvaluator(ExpressionEvaluator) registerEvaluator()} function they will be lost.
+     */
+    public synchronized void refresh()
+    {
+        m_evaluators.clear();
+        NamingEnumeration list = null;
+        try
+        {
+            Context initialContext = new InitialContext();
+            list = initialContext.list( QUERY_EVALUATOR_CONTEXT );
+            NameClassPair pair = null;
+            ExpressionEvaluator evaluator = null;
+            while ( list.hasMore() )
+            {
+                pair = (NameClassPair) list.next();
+                evaluator =
+                        (ExpressionEvaluator) JNDIUtils.lookup( initialContext,
+                                QUERY_EVALUATOR_CONTEXT + "/" + pair.getName(),
+                                ExpressionEvaluator.class );
+                registerEvaluator( evaluator );
+            }
+        }
+        catch ( NamingException ne )
+        {
+            LOG.error( MSG.getMessage( Keys.QUERY_ENG_INIT_ERROR, ne ) );
+        }
+        finally
+        {
+            if ( list != null )
             {
-               list.close(  );
+                try
+                {
+                    list.close();
+                }
+                catch ( NamingException ee )
+                {
+                }
             }
-            catch ( NamingException ee )
+        }
+    }
+
+    /**
+     * DOCUMENT_ME
+     *
+     * @param evaluator DOCUMENT_ME
+     */
+    public synchronized void registerEvaluator( ExpressionEvaluator evaluator )
+    {
+        URI[] dialects = evaluator.getSupportedDialects();
+        for ( int i = 0; i < dialects.length; i++ )
+        {
+            m_evaluators.put( dialects[i], evaluator );
+        }
+    }
+
+    /**
+     * @param dialect
+     * @param evaluator
+     *
+     * @throws UnknownQueryExpressionDialectFaultException
+     *
+     */
+    public void registerEvaluator( URI dialect,
+                                   ExpressionEvaluator evaluator )
+            throws UnknownQueryExpressionDialectException
+    {
+        URI[] supportedDialects = evaluator.getSupportedDialects();
+        boolean isSupportedDialect = false;
+        for ( int i = 0; i < supportedDialects.length; i++ )
+        {
+            if ( supportedDialects[i].equals( dialect ) )
             {
+                isSupportedDialect = true;
             }
-         }
-      }
-   }
-
-   /**
-    * DOCUMENT_ME
-    *
-    * @param evaluator DOCUMENT_ME
-    */
-   public synchronized void registerEvaluator( ExpressionEvaluator evaluator )
-   {
-      URI[] dialects     = evaluator.getSupportedDialects(  );
-      for ( int i = 0; i < dialects.length; i++ )
-      {
-         m_evaluators.put( dialects[i], evaluator );
-      }
-   }
-
-   /**
-    *
-    * @param dialect
-    * @param evaluator
-    *
-    * @throws UnknownQueryExpressionDialectFaultException
-    *
-    */
-   public void registerEvaluator( URI                 dialect,
-                                  ExpressionEvaluator evaluator )
-   throws UnknownQueryExpressionDialectException
-   {
-      URI[]   supportedDialects  = evaluator.getSupportedDialects(  );
-      boolean isSupportedDialect = false;
-      for ( int i = 0; i < supportedDialects.length; i++ )
-      {
-         if ( supportedDialects[i].equals( dialect ) )
-         {
-            isSupportedDialect = true;
-         }
-      }
-
-      if ( isSupportedDialect )
-      {
-         m_evaluators.put( dialect, evaluator );
-      }
-      else
-      {
-         throw new UnknownQueryExpressionDialectException( dialect );
-      }
-   }
+        }
+        if ( isSupportedDialect )
+        {
+            m_evaluators.put( dialect, evaluator );
+        }
+        else
+        {
+            throw new UnknownQueryExpressionDialectException( dialect );
+        }
+    }
 }

Modified: incubator/apollo/trunk/src/java/org/apache/ws/resource/properties/query/xpath/impl/JaxenXPathExpressionEvaluator.java
URL: http://svn.apache.org/viewcvs/incubator/apollo/trunk/src/java/org/apache/ws/resource/properties/query/xpath/impl/JaxenXPathExpressionEvaluator.java?rev=168465&r1=168464&r2=168465&view=diff
==============================================================================
--- incubator/apollo/trunk/src/java/org/apache/ws/resource/properties/query/xpath/impl/JaxenXPathExpressionEvaluator.java (original)
+++ incubator/apollo/trunk/src/java/org/apache/ws/resource/properties/query/xpath/impl/JaxenXPathExpressionEvaluator.java Thu May  5 16:30:35 2005
@@ -28,7 +28,6 @@
 import org.apache.ws.resource.properties.query.xpath.XPathExpression;
 import org.apache.ws.util.i18n.Messages;
 import org.apache.ws.util.xml.NamespaceContext;
-import org.apache.xalan.Version;
 import org.apache.xmlbeans.XmlObject;
 import org.jaxen.JaxenException;
 import org.jaxen.XPath;
@@ -38,9 +37,8 @@
 import java.net.URI;
 
 /**
- * An XPath expression evaluator that utilizes the opensource Jaxen XPath
- * evaluation engine.
- * 
+ * An XPath expression evaluator that utilizes the Jaxen XPath evaluation engine.
+ *
  * LOG-DONE
  */
 public class JaxenXPathExpressionEvaluator
@@ -156,7 +154,7 @@
      */
     public String toString()
     {
-        return ( MSG.getMessage( Keys.XALAN_VERSION, Version.getVersion() + ")" ).intern() );
+        return ( MSG.getMessage( Keys.JAXEN_EVALUATOR ) );
     }
 
     protected class JaxenNamespaceContext implements org.jaxen.NamespaceContext

Modified: incubator/apollo/trunk/src/java/org/apache/ws/resource/properties/query/xpath/impl/XalanXPathExpressionEvaluator.java
URL: http://svn.apache.org/viewcvs/incubator/apollo/trunk/src/java/org/apache/ws/resource/properties/query/xpath/impl/XalanXPathExpressionEvaluator.java?rev=168465&r1=168464&r2=168465&view=diff
==============================================================================
--- incubator/apollo/trunk/src/java/org/apache/ws/resource/properties/query/xpath/impl/XalanXPathExpressionEvaluator.java (original)
+++ incubator/apollo/trunk/src/java/org/apache/ws/resource/properties/query/xpath/impl/XalanXPathExpressionEvaluator.java Thu May  5 16:30:35 2005
@@ -159,7 +159,7 @@
      */
     public String toString()
     {
-        return ( MSG.getMessage( Keys.XALAN_VERSION, Version.getVersion() + ")" ).intern() );
+        return ( MSG.getMessage( Keys.XALAN_EVALUATOR, Version.getVersion() ) );
     }
 
     private Object normalizeResult( XObject xResult )

Modified: incubator/apollo/trunk/src/java/org/apache/ws/resource/properties/v2004_06/porttype/impl/QueryResourcePropertiesPortTypeImpl.java
URL: http://svn.apache.org/viewcvs/incubator/apollo/trunk/src/java/org/apache/ws/resource/properties/v2004_06/porttype/impl/QueryResourcePropertiesPortTypeImpl.java?rev=168465&r1=168464&r2=168465&view=diff
==============================================================================
--- incubator/apollo/trunk/src/java/org/apache/ws/resource/properties/v2004_06/porttype/impl/QueryResourcePropertiesPortTypeImpl.java (original)
+++ incubator/apollo/trunk/src/java/org/apache/ws/resource/properties/v2004_06/porttype/impl/QueryResourcePropertiesPortTypeImpl.java Thu May  5 16:30:35 2005
@@ -58,10 +58,6 @@
     private static final Log LOG = LogFactory.getLog( QueryResourcePropertiesPortTypeImpl.class );
     private static final Messages MSG = MessagesImpl.getInstance();
     private static final NamespaceVersionHolder NAMESPACE_SET = new NamespaceVersionHolderImpl() ;
-
-    /**
-     * DOCUMENT_ME
-     */
     private static final QueryEngine QUERY_ENGINE = new QueryEngineImpl();
 
     /**

Modified: incubator/apollo/trunk/src/java/org/apache/ws/resource/properties/v2004_11/porttype/impl/QueryResourcePropertiesPortTypeImpl.java
URL: http://svn.apache.org/viewcvs/incubator/apollo/trunk/src/java/org/apache/ws/resource/properties/v2004_11/porttype/impl/QueryResourcePropertiesPortTypeImpl.java?rev=168465&r1=168464&r2=168465&view=diff
==============================================================================
--- incubator/apollo/trunk/src/java/org/apache/ws/resource/properties/v2004_11/porttype/impl/QueryResourcePropertiesPortTypeImpl.java (original)
+++ incubator/apollo/trunk/src/java/org/apache/ws/resource/properties/v2004_11/porttype/impl/QueryResourcePropertiesPortTypeImpl.java Thu May  5 16:30:35 2005
@@ -58,10 +58,6 @@
     private static final Log LOG = LogFactory.getLog( QueryResourcePropertiesPortTypeImpl.class );
     private static final Messages MSG = MessagesImpl.getInstance();
     private static final NamespaceVersionHolder NAMESPACE_SET = new NamespaceVersionHolderImpl();
-
-    /**
-     * DOCUMENT_ME
-     */
     private static final QueryEngine QUERY_ENGINE = new QueryEngineImpl();
 
     /**



---------------------------------------------------------------------
To unsubscribe, e-mail: apollo-dev-unsubscribe@ws.apache.org
For additional commands, e-mail: apollo-dev-help@ws.apache.org
--- incubator/apollo/trunk/src/java/org/apache/ws/resource/properties/query/QueryEngine.java (original)
+++ incubator/apollo/trunk/src/java/org/apache/ws/resource/properties/query/QueryEngine.java Thu May  5 16:30:35 2005
@@ -16,7 +16,6 @@
 package org.apache.ws.resource.properties.query;
 
 import org.apache.ws.resource.properties.ResourcePropertySet;
-import org.w3c.dom.Element;
 
 import java.net.URI;
 
@@ -29,55 +28,79 @@
  */
 public interface QueryEngine
 {
-   /**
-    * Gets the evaluator currently registered to handle an expression of the specified qualified name (from the top
-    * level element of the XML Schema definition of the expression)
-    *
-    * @return the matching expression evaluator or null if none was found
-    */
-   public ExpressionEvaluator getEvaluator( URI dialect );
-
-   /**
-    * registers a new evaluator that can be used to evaluate queries on a service.
-    *
-    * @param evaluator implementation of evaluator to be used for evaluating queries specified in its XML Schema
-    *                  definition.
-    */
-   public void registerEvaluator( ExpressionEvaluator evaluator );
-
-   /**
-    * DOCUMENT_ME
-    *
-    * @param dialect   DOCUMENT_ME
-    * @param evaluator DOCUMENT_ME
-    *
-    * @throws UnknownQueryExpressionDialectException
-    *          DOCUMENT_ME
-    */
-   public void registerEvaluator( URI                 dialect,
-                                  ExpressionEvaluator evaluator )
-   throws UnknownQueryExpressionDialectException;
-
-   /**
-    * Executes a query against a resource property set. The appropraite ExpressionEvaluator is used for the query based
-    * on the dialect attribute.
-    *
-    * @param queryExpr       query expression
-    * @param resourcePropSet resource properties set to execute the query against
-    * @return the result of the evaluation which depends on the expression. The results must be an xml serializable
-    *         object in order to be passed back correctly to a remote client. The easiest way of achieving this is to
-    *         model it as a Bean, or simply return a <code>SOAPElment</code> or <code>DOM Element</code>. If the result
-    *         object returned is null an empty query result is returned.
-    *
-    * @throws UnknownQueryExpressionDialectException
-    *                                       if query dialect is unsupported
-    * @throws QueryEvaluationErrorException if query evaluation fails
-    * @throws InvalidQueryExpressionException
-    *                                       if query expression is invalid
-    */
-   Object executeQuery( QueryExpression queryExpr,
-                        ResourcePropertySet resourcePropSet )
-   throws UnknownQueryExpressionDialectException, 
-          QueryEvaluationErrorException, 
-          InvalidQueryExpressionException;
+    /**
+     * Gets the evaluator currently registered to handle an expression of the specified qualified name (from the top
+     * level element of the XML Schema definition of the expression)
+     *
+     * @return the matching expression evaluator or null if none was found
+     */
+    ExpressionEvaluator getEvaluator( URI dialect );
+
+    /**
+     * Registers a new evaluator that can be used to evaluate queries on a service.
+     *
+     * @param evaluator implementation of evaluator to be used for evaluating queries specified in its XML Schema
+     *                  definition.
+     */
+    void registerEvaluator( ExpressionEvaluator evaluator );
+
+    /**
+     * Registers a query expression evaluator for handling query expressions in
+     * specified dialect.
+     *
+     * @param dialect   a query expression dialect
+     * @param evaluator a query expression evaluator
+     *
+     * @throws UnknownQueryExpressionDialectException if the evaluator does not supoport the specified dialect
+     */
+    void registerEvaluator( URI dialect,
+                            ExpressionEvaluator evaluator )
+            throws UnknownQueryExpressionDialectException;
+
+    /**
+     * Executes a query against a resource property set. The appropriate
+     * ExpressionEvaluator is used for the evalution based on the dialect
+     * attribute.
+     *
+     * @param queryExpr       a query expression
+     * @param resourcePropSet the resource properties set to evluate the query expression against
+     *
+     * @return the result of the evaluation which depends on the expression. The results must be an xml serializable
+     *         object in order to be passed back correctly to a remote client. The easiest way of achieving this is to
+     *         model it as a Bean, or simply return a <code>SOAPElement</code> or <code>DOM Element</code>. If the
+     *         result object returned is null an empty query result is returned.
+     *
+     * @throws UnknownQueryExpressionDialectException if query dialect is unsupported
+     * @throws QueryEvaluationErrorException          if query evaluation fails
+     * @throws InvalidQueryExpressionException        if query expression is invalid
+     */
+    Object executeQuery( QueryExpression queryExpr,
+                         ResourcePropertySet resourcePropSet )
+            throws UnknownQueryExpressionDialectException,
+            QueryEvaluationErrorException,
+            InvalidQueryExpressionException;
+
+    /**
+     * Evaluates the expression over the specified context object and returns the result.
+     * The appropriate ExpressionEvaluator is used for the evaluation based on the dialect
+     * attribute.
+     *
+     * @param queryExpr   a query expression
+     * @param evalContext the context to evaluate the query expression against
+     *
+     * @return the result of the evaluation which depends on the expression. The results must be an xml serializable
+     *         object in order to be passed back correctly to a remote client. The easiest way of achieving this is to
+     *         model it as a Bean, or simply return a <code>SOAPElement</code> or <code>DOM Element</code>. If the
+     *         result object returned is null an empty query result is returned.
+     *
+     * @throws UnknownQueryExpressionDialectException if query dialect is unsupported
+     * @throws QueryEvaluationErrorException          if query evaluation fails
+     * @throws InvalidQueryExpressionException        if query expression is invalid
+     */
+    Object executeQuery( QueryExpression queryExpr,
+                         Object evalContext )
+            throws UnknownQueryExpressionDialectException,
+            QueryEvaluationErrorException,
+            InvalidQueryExpressionException;
+
 }

Modified: incubator/apollo/trunk/src/java/org/apache/ws/resource/properties/query/impl/QueryEngineImpl.java
URL: http://svn.apache.org/viewcvs/incubator/apollo/trunk/src/java/org/apache/ws/resource/properties/query/impl/QueryEngineImpl.java?rev=168465&r1=168464&r2=168465&view=diff
==============================================================================